@@ -55,7 +55,7 @@ class AtlantisClient:
                 'code': code,
                 'client_id': self.client_id,
                 'client_secret': self.client_secret,
-                'redirect_uri': self.redirect_uri,
+                'redirect_uri': redirect_uri,
                 'grant_type': 'authorization_code'
             })
         response.raise_for_status()
